@@ -128,7 +128,7 @@ class App:
                         if type == "route":
                             response = handler(request, **kwargs)
                         else:
-                            response = handler(websocket, **args)
+                            response = handler(websocket, **kwargs)
                 else:
                     return self.default_response(request)
 
