@@ -1,17 +1,15 @@
-"""
-The below is COMING SOON
-"""
-
-
-from arc.middleware import Middleware
 from starlette.requests import Request
 import secrets
 
 
 class SessionHandler:
-    def __init__(self, app, secret_key=None):
+    def __init__(self, app, lifetime=None, secret_key=None):
         self.app = app
-        self.lifetime = self.app.to_seconds(1, "hour")
+        
+        if lifetime is None:
+            self.lifetime = self.app.to_seconds(1, "hour")
+        else:
+            lifetime = self.lifetime
 
         self.secret_key = secrets.token_urlsafe()
 
@@ -23,20 +21,20 @@ class SessionHandler:
             response.set_cookie("secret_key", key+self.secret_key,
                                 httponly=True, max_age=self.lifetime)
 
-            self._dict[key] = {}
+            self._dict = {}
 
             self.initialized = True
 
-        self.initialized = True
+            self.app.config["SECRET_KEY"] = key+self.secret_key
+            self.app.config["SESSION"] = {}
+
+            return
+
+        if request.cookies.get("secret_key") == self.app.config["SECRET_KEY"]:
+            self.initialized = True
+        else:
+            raise ValueError("Invald Secret Key")
 
     def __call__(self):
         assert self.initialized, "Session Not Initialized"
-        return self._dict
-
-
-# class SessionMiddleware(Middleware):
-#     def process_request(self, req):
-#         self.app.scope["current_secret"] = req.cookies.get("secret_key")
-
-#     def process_response(self, req, res):
-#         pass
+        return self.app.config["SESSION"]
